Opinions & Announcements Search
Description: Opinion Site
Keywords: Decisions, Opinions, Files, Documents, Reporter

# The Supreme Court of Ohio & The Ohio Judicial System

## Opinions & Announcements
Source: |
Decided: |
WebCite No: |
Full Text: |
Enter either a webcite number or a full text query.
Columns to Include
Case Name Case No Topics/Issues | Author County Citation | Decided Date Posted Date WebCite
Notices
Supreme Court opinions and Supreme Court announcements are usually posted weekdays at 9:00 a.m. Other documents are posted as received by the court.
All documents are in the Adobe® PDF format. The Adobe® Reader® is a free download. |
| Rows per Page

189 documents were found matching the selected criteria.
Page: [ 1] 2 next

Case Name | Case No. | Topics and Issues | Author | Decided | WebCite
--- | --- | --- | --- | --- | ---
State v. Estes | CA2013-12-126 | Heroin possession; drug paraphernalia possession; drug and drug paraphernalia discovered underneath backseat of the cruiser after defendant exited the back of the cruiser; manifest weight of the evidence; DNA on cut straw was not defendant's DNA; state's failure to identify the source of the DNA on cut straw did not violate defendant's due process rights. | M. Powell | 7/28/2014 | 2014-Ohio-3295
In re R.L.S. | CA2013-12-117 | Residential parent; relocation; parenting time; modification; change of circumstances; in camera interview; competency; child. | Ringland | 7/28/2014 | 2014-Ohio-3294
In re Estate of Rush | CA2013-10-103 | R.C. 2107.12; Standing; Persons Interested; R.C. 2107.11; Jurisdiction to Probate; Estoppel. | Ringland | 7/28/2014 | 2014-Ohio-3293
CitiMortgage, Inc. v. Davis | CA2013-09-088 | Motion to Dismiss, Standing, Motion for Summary Judgment, Foreclosure, Note, Mortgage. | M. Powell | 7/28/2014 | 2014-Ohio-3292
Smith v. Pierce Twp. | CA2013-10-079 | Political Subdivision Employee Immunity; Malice; Invasion of Privacy; Wrongful Intrusion; Breach of Contract; Attorney; Client; Quantum Meruit; Promissory Estoppel; Invasion of Privacy; Publicity. | Ringland | 7/28/2014 | 2014-Ohio-3291
In re Z.C. | CA2014-02-049; CA2014-02-050 | Permanent custody; best interest; clean house; legally secure placement. | Piper | 7/28/2014 | 2014-Ohio-3290
In re Hamblin | CA2013-04-061 | R.C. 2919.24(A)(1), 2151.022; Contributing to Unruliness or Delinquency of a Child: To convict an accused of contributing to the unruliness or delinquency of a child under R.C. 2919.24(A)(1), the state is required to show only that the accused aided, abetted, induced, caused, encouraged, or contributed to a child becoming unruly or delinquent; the state need not prove that the child was formally adjudicated as an unruly child. | Piper | 7/28/2014 | 2014-Ohio-3289
State ex rel. Podolsky v. Wenninger | CA2013-12-019 | Motion to unseal court records related to acquittal of county sheriff filed by county resident and online newsletter; motion properly denied by trial court on ground resident and newsletter did not qualify as individuals permitted access to sealed records under R.C. 2953.53(D); motion to unseal not a taxpayer's action pursuant to R.C. 309.13; Sup.R. 44 through 47 inapplicable; resident and newsletter not entitled to sealed court records under R.C. 149.43; court records properly sealed following acquittal of sheriff; trial court not required to conduct balancing test of the private and public interests under R.C. 2953.52 anew whenever a request to unseal records is filed, absent unusual and exceptional circumstances; individual whose records are sealed not required to relitigate the case and establish anew that his privacy interest continues to outweigh the public interest in accessing the records whenever a request to unseal records is filed, absent unusual and exceptional circumstances. | M. Powell | 7/28/2014 | 2014-Ohio-3288
Dimitriou v. Dimitriou | CA2013-05-045 | The trial court properly found appellant in contempt where there was clear and convincing evidence that appellant knew of his support orders, failed to pay them, and did not prove that he has the inability to pay. Despite Appellant's lack of income, appellant presented no evidence that he did not have the capacity to earn more money in order to abide by the support orders. | Piper | 7/21/2014 | 2014-Ohio-3189
In re A.W. | CA2014-03-005 | Permanent Custody; Manifest Weight of the Evidence; Best Interest of the Child; The juvenile court did not err and acted in the best interest of the child by granting permanent custody to appellee, the Fayette County Department of Job and Family Services, Children Services Division, where appellant, who suffered from depression and severe anxiety, was twice found under the influence of drugs or alcohol while caring for her daughter, defied court orders by leaving her daughter in the care of certain individuals, and exhibited an inability to maintain financial stability. | S. Powell | 7/21/2014 | 2014-Ohio-3188
State v. McCord | CA2013-12-096 | Appellant appeals the trial court's decision denying his motion for postconviction relief. Appellant argues his sentence was void because the trial court failed to notify him at the time of sentencing of a potential community service requirement if he failed to pay court costs, and because the trial court imposed postrelease control for the unspecified felony of murder. The trial court properly ruled appellant's argument of a void sentence due to the trial court's failure to notify him of a potential community service requirement was barred by res judicata where appellant failed to appeal the trial court's prior rulings on the issue, and where the language of the statute at the time of sentencing does not support appellant's argument. The trial court properly ruled appellant's argument of a void sentence due to the trial court's imposition of postrelease control for the unspecified felony of murder was barred by res judicata where appellant failed to appeal the trial court's prior rulings on the issue, and where appellant's argument was rendered moot by a nunc pro tunc entry in 2011. | S. Powell | 7/21/2014 | 2014-Ohio-3187
State v. Ossege | CA2013-11-086, CA2013-11-087 | OVI; R.C. 4511.19; R.C. 2919.22; mens rea; substantial compliance; equal protection clause; motion to suppress. | Hendrickson | 7/21/2014 | 2014-Ohio-3186
Reed v. Triton Servs., Inc. | CA2013-07-055, CA2013-07-060 | Specific Performance; Equitable Defenses; Money Damages; Stock; Shares. | Ringland | 7/21/2014 | 2014-Ohio-3185
Bank of New York Mellon v. Brock | CA2014-01-003 | Motion to strike; motion for summary judgment; Civ.R. 56(C); Civ.R. 56(E); documents attached to affidavits; evidentiary materials; genuine issue of material fact; Fair Debt Collection Practices Act; debt collector; timing of assignment of debt. | Hendrickson | 7/14/2014 | 2014-Ohio-3085
Huntington Natl. Bank Mtge. Loan Dept. v. Peppel | CA2013-11-114 | Appellant appeals a decision of the trial court granting summary judgment to appellee in a foreclosure action. Appellee did not fail to satisfy its burden of producing evidence that affirmatively demonstrates the absence of a genuine issue of material fact where it did not attach business records to a sworn affidavit by appellee asserting the loan was in default. Appellant's failure to move the trial court to strike that portion of the affidavit waived his challenge to the affidavit on appeal. In ruling on the motion for summary judgment, the trial court was not required to consider as evidence appellant's Memorandum in Opposition or his Motion for Leave to File an Amended Answer. These materials are not included in Civ.R. 56(C)'s exclusive list of materials the trial court may consider for summary judgment motions. | Ringland | 7/14/2014 | 2014-Ohio-3084
Wilmington v. Lubbers | CA2013-06-013 | Motion to suppress; traffic violation; slow speed violation; probable cause to believe traffic violation occurred. | Hendrickson | 7/14/2014 | 2014-Ohio-3083
Pangallo v. Adkins | CA2014-02-019 | Summary Judgment; R.C. 955.28(B); Common Law Negligence; Dog Bite; Landlord; Harborer; The trial court did not err by granting appellee's motion for summary judgment regarding appellant's claims under R.C. 955.28(B) and common law negligence where appellee was not the harborer of his tenant's dog that caused appellant's injuries. The incident did not occur in any common area shared by appellee and the tenant, but rather, at the bottom of the lone staircase leading up to the tenant's second floor apartment. The staircase, just as the apartment itself, was an area where the tenant exhibited sole possession and control. | S. Powell | 7/14/2014 | 2014-Ohio-3082
Holcomb v. Holcomb | CA2013-10-080 | Summary judgment; open and obvious; attendant circumstances; active negligence; assumed duty. | Ringland | 7/14/2014 | 2014-Ohio-3081
State v. Taylor | CA2013-10-186 | Crim.R. 32.1; motion to withdraw guilty plea; hearing. | Ringland | 7/14/2014 | 2014-Ohio-3080
State v. Farmer | CA2013-06-097 | Manifest Weight; Cruelty to a Companion Animal; R.C. 959.13(B). | Ringland | 7/14/2014 | 2014-Ohio-3079
Batty v. Batty | CA2013-06-088 | The trial court did not abuse its discretion by not ordering appellee to submit to random drug screening, by ordering unsupervised visitation, and by not ordering appellee to submit proof that she was attending the court-ordered counseling sessions where there was no evidence presented to establish that these conditions were necessary and where the trial court properly balanced the R.C. 3109.051(D) visitation factors. | Piper | 7/14/2014 | 2014-Ohio-3078
State v. Wyatt | CA2013-06-005 | The trial court properly overruled appellant's motion to suppress because the search warrant was issued on probable cause where the officer/affiant gave details supporting his belief that drug-related charges were occurring on the property and because appellant voluntarily waived his Sixth Amendment rights by asking to speak to police after he had been arraigned and appointed counsel. Appellant's convictions were supported by sufficient evidence and not rendered against the manifest weight of the evidence where the state presented evidence that appellant knowingly possessed chemicals and materials necessary for the manufacturing of methamphetamine, such as appellant's fingerprints on the finished narcotic and a first-hand witness' testimony that appellant carried materials into the laboratory. Appellant does not have a constitutional right to a plea bargain, so that the state did not violate any of appellant's rights by withdrawing its plea offer upon appellant's decision to move forward with the suppression hearing. | Piper | 7/7/2014 | 2014-Ohio-3009
State v. Kievman | CA2013-11-081 | Right to Counsel; Ineffective Waiver: Appellant's waiver of the right to counsel was ineffective since trial court did not fully advise her of the nature of all of the charges against her, the range of allowable punishments for all of the charges, the possible defenses to the charges or the circumstances in mitigation thereof. | Ringland | 7/7/2014 | 2014-Ohio-3008
State v. Fields | CA2013-11-105 | Appellant's convictions were supported by sufficient evidence and not rendered against the manifest weight of the evidence where the state presented evidence that appellant punched the corrections officer in the face and then refused to obey the commands of other corrections officers to stop resisting when they tried to restore peace in the area where the attack occurred. The trial court did not abuse its discretion by ordering appellant to be restrained during the trial where the court heard evidence that appellant had several previous convictions for assaulting guards and corrections officers, and that appellant had a history of violence. The trial court did not abuse its discretion by finding incident reports and other parts of the corrections officer's personnel file inadmissible where such reports were irrelevant and would not help the jury understand the circumstances surrounding the incident. The cumulative error doctrine was inapplicable because no errors occurred during the trial that denied appellant the right to a fair trial. The trial court properly found that appellant's convictions for obstructing official business and assault did not merge were the acts were committed with separate conduct and a separate animus. | Piper | 6/30/2014 | 2014-Ohio-2900
Kranz v. Kranz | CA2013-10-102 | Motion for change of custody; motion for contempt; child support; guardian ad litem; in chambers interview; R.C. 3109.04(B); Civ.R. 7(B). | Hendrickson | 6/30/2014 | 2014-Ohio-2899
State v. Hobbs | CA2013-10-098 | Anders no error. | Per Curiam | 6/30/2014 | 2014-Ohio-2898
Sterling Constr., Inc. v. Alkire | CA2013-08-028, CA2013-08-030 | The trial court improperly found that the Consumer Sales Practices Act did not apply to a consumer transaction wherein the appellant agreed to pay for appellee's remodeling services because the court determined that the parties had a personal relationship that took their transaction out of the Act's purview. The trial court improperly found that the parties did not enter into an implied contract where the terms were not concrete, but there was a tacit understanding that the appellant agreed to pay for services and appellee agreed to provide such services. | Piper | 6/30/2014 | 2014-Ohio-2897
In re D.K.W. | CA2014-02-001 | Permanent custody; best interest; motion to continue permanent custody hearing to explore potential placement with relatives, denied; Juv.R. 23. | M. Powell | 6/30/2014 | 2014-Ohio-2896
State v. Snead | CA2014-01-014 | Res Judicata, Sentencing, Sexual Predator, Postrelease Control, Plea Colloquy. | S. Powell | 6/30/2014 | 2014-Ohio-2895
State v. Webb | CA2014-01-013 | Motion for New Trial; No Brady Violation; Alternative Suspects; Newly-Discovered Evidence; Fire Science; The trial court did not err by denying appellant's motion for a new trial based on an alleged Brady violation where the purported evidence of two alternative suspects was not material in that there exists no reasonable probability that the result of the trial would have been different had the evidence been disclosed to defense. The record contains extensive and overwhelming evidence establishing appellant's guilt, including a vast array of physical evidence implicating him in the crime, as well as a clearly defined motive for wanting his entire family dead. The trial court also did not err by denying appellant's motion for a new trial based on new advances in so-called "fire science" where the evidence merely impeached and was contradictory to the evidence presented by the state at trial regarding the origins of the fire. Contrary to appellant's claims, unlike DNA evidence, the alleged "newly discovered" evidence regarding fire investigations cannot be construed as definite proof that appellant did not start the fire. | S. Powell | 6/30/2014 | 2014-Ohio-2894
Reynolds-Cornett v. Reynolds | CA2013-09-175 | Attorney fees, child support, imputed income, overtime pay, gross income, R.C. 3105.73(B), R.C. 3119.05. | S. Powell | 6/30/2014 | 2014-Ohio-2893
In re W.F. | CA2014-01-002 | Permanent custody; adjudication; dependency; appeal; final appealable order; ineffective assistance of counsel. | Piper | 6/30/2014 | 2014-Ohio-2892
State v. Berry | CA2013-11-084 | Appellant appeals a $10,000 judgment against it entered by the Clermont County Municipal Court. A former agent of appellant executed a $10,000 bond to secure the release of a criminal defendant. The criminal defendant failed to appear for his sentencing hearing, and appellant failed to appear at the subsequent bond forfeiture proceedings to show cause as to why it should not be liable. Thereafter, the trial court entered judgment against it on the bond. Where appellant's own exhibit shows that the criminal defendant was not incarcerated in another jurisdiction until after the criminal defendant had failed to appear three times, including the bond forfeiture proceeding, a showing of incarceration is not good cause to release the surety from liability on the bond. Where appellant's Civ.R. 60(B) motion for relief from judgment does not show that fraud, misrepresentation, or misconduct of the other party prevented it from fully and fairly presenting its defense to liability on the bond, appellant fails to allege operative facts justifying relief under Civ.R. 60(B)(3). Additionally, appellant failed to show excusable neglect where the facts and circumstances showed that considerations of fairness did not outweigh the need for finality of judgments. | Hendrickson | 6/23/2014 | 2014-Ohio-2715
Bank of Am., N.A. v. Brooks | CA2013-11-219 | Final appealable order; Civ.R. 54(B); R.C. 2505.02(B); order of sale; foreclosure. | Ringland | 6/23/2014 | 2014-Ohio-2714
In re C.E.J. | CA2013-04-059 | Conflict of Interests; Guardian Ad Litem; Child's Best Interest; Child Support Order; Visitation Schedule; Tax Exemption; Health Insurance Determination. | Ringland | 6/23/2014 | 2014-Ohio-2713
Black v. Sakelios | CA2013-10-094 | Plaintiff-appellant appeals from the Warren County Court of Common Pleas decision finding he was not entitled to the return of personal property he had given to relatives of his former girlfriend while living in her house. He also challenges two evidentiary rulings by the trial court, and the trial court's imposition of sanctions on him for failing to attend a court-ordered mediation session prior to the trial. Appellee's failure to plead a "gift defense" did not preclude a finding that appellant gifted some of his property to appellee's relatives, where the issue of gift was raised to disprove appellant's claims and not to assert an affirmative defense. Under Civ.R. 53(D), appellant may not raise evidentiary issues regarding the introduction of appellee's credit card statements on appeal because he did not raise the objections before the trial court. Plain error will be recognized only in extremely rare cases involving exceptional circumstances that call into question the basic fairness or integrity of the judicial process; there are no such circumstances here. The trial court did not abuse its discretion when it declined to allow appellant's testimony regarding a repair estimate he received for his plasma screen television. The estimate constituted inadmissible hearsay because appellant did not call the authors of the estimate as witnesses or anyone else who could authenticate the estimate. The trial court did not abuse its discretion when it imposed sanctions on appellant for failing to appear at a court-ordered mediation prior to trial. The court acted within its authority and limited the sanctions only to actual costs incurred for the mediator and appellee's attorney fees. | M. Powell | 6/16/2014 | 2014-Ohio-2587
State v. Casey | CA2013-10-090 | Motion to Suppress; Reasonable Suspicion; Possession of Marijuana. | Hendrickson | 6/16/2014 | 2014-Ohio-2586
Ownerland Realty, Inc. v. Zhang | CA2013-09-077, CA2013-10-097 | Summary judgment; fraudulent inducement; unjust enrichment; attorney fees; frivolous conduct. | Hendrickson | 6/16/2014 | 2014-Ohio-2585
State v. Shalash | CA2013-06-052 | Controlled Substance Analog; Void-For-Vagueness: R.C. 3719.01(HH)'s definition of "controlled substance analog" is not unconstitutionally vague as the term is clearly and specifically defined, in words readily comprehensible to the ordinary reader and provides adequate notice of what conduct is prohibited, as the statute clearly provides that substances that have been chemically designed to be similar to controlled substances, but which are not themselves listed on the controlled substance schedules, will nonetheless be considered as schedule I or II controlled substances if they (1) are substantially similar chemically to drugs that are on those schedules and (2) produce similar effects on the central nervous system as substances that are on those schedules or are intended or represented to produce effects similar to those produced by substances that are on those schedules. Daubert Hearing: The decision on whether hold a Daubert hearing is a matter within the trial court's sound discretion, but the trial court abuses its discretion where a novel issue of law in this state is presented. | Hendrickson | 6/16/2014 | 2014-Ohio-2584
State v. Rodriguez | CA2013-11-011 | Public Records Request; R.C. 149.43(B)(8); No Justiciable Claim; The trial court did not err by denying appellant's most recent public records request where appellant, who is an inmate, already received the requested documentation on two occasions and otherwise failed to establish any justiciable claim for which the items he sought would be material. | S. Powell | 6/16/2014 | 2014-Ohio-2583
State v. Kwambana | CA2013-12-092 | Allied Offenses of Similar Import; R.C. 2941.25; Kidnapping; Separate Victims; Separate Animus; The trial court did not err by failing to merge appellant's four kidnapping convictions for the purpose of sentencing where each offense was committed against a separate victim. A kidnapping that involves multiple kidnapping victims necessarily includes a finding of a separate animus for each kidnapping offense. | S. Powell | 6/16/2014 | 2014-Ohio-2582
State v. Grindstaff | CA2013-09-074 | R.C. 4511.19(A)(1); OVI; operating a vehicle while under the influence of alcohol; impairment; failure to appear; flight; consciousness of guilt; jury instruction; abuse of discretion; prosecutorial misconduct; manifest weight of the evidence; sufficiency of the evidence; Crim.R. 29(C); motion for acquittal. | Hendrickson | 6/16/2014 | 2014-Ohio-2581
In re G.F. | CA2013-12-248 | Permanent Custody; Manifest Weight; New Counsel; Split Roles; Guardian Ad Litem. | Ringland | 6/16/2014 | 2014-Ohio-2580
In re G.W. | CA2013-12-246 | Permanent custody, legal custody; ineffective assistance of counsel, failure to file motion. | S. Powell | 6/16/2014 | 2014-Ohio-2579
Jackson v. Hogeback | CA2013-10-187 | Directed verdict; vicarious liability; outside scope of employment; negligent hiring; negligent supervision; negligent retention; summary judgment. | Piper | 6/16/2014 | 2014-Ohio-2578
Bank of Am., N.A. v. Jackson | CA2014-01-018 | The trial court did not abuse its discretion in denying appellant's motion to strike portions of an affidavit offered by appellee to demonstrate its right to foreclose where the affidavit was based on personal knowledge of the affiant and made reference to admissible business records. The trial court did not err in overruling appellant's motion to compel appellee to produce the original note where appellant did not raise a genuine issue as to the authenticity of the original and it was not otherwise unfair to admit the duplicate in lieu of the original note. Summary judgment was appropriate where the appellee demonstrated that it held the note and mortgage, appellant had defaulted on the note, and the amount due was accelerated. | Piper | 6/9/2014 | 2014-Ohio-2480
Asset Mgt. West 9, L.L.C. v. McBrayer | CA2014-02-004 | Summary judgment was proper where there were no genuine issues of material fact, and the record demonstrated that appellee held the note and mortgage, appellant defaulted on the loan, and the total amount due and owing was accelerated. | Piper | 6/9/2014 | 2014-Ohio-2479
Fears v. Cooper | CA2013-12-037 | The trial court properly dismissed appellant's petition for a writ of habeas corpus where appellant's petition was not properly supported with his commitment papers, and where the petition was not the proper method for challenging the sufficiency of the indictments or the constitutionality of the statutes under which appellant was convicted. | Piper | 6/9/2014 | 2014-Ohio-2478
Briggs v. Franklin Pre-Release Ctr. | CA2013-10-035 | Workers' Compensation, Substantial Aggravation, Pre-existing Condition, R.C. 4123.04, Civ.R. 50, JNOV, Judgment Notwithstanding the Verdict. | M. Powell | 6/9/2014 | 2014-Ohio-2477
Estate of Everhart v. Everhart | CA2013-07-019 CA2013-09-026 | Strike Jury Demand; Civ.R. 38; Civ.R. 39; Waiver of Jury Trial; Common Law Marriage; Undue Influence; Property Transfer; Deed Execution; Rescission; Amend Pleadings' Civ.R. 15(B); Unjust Enrichment. | Ringland | 6/9/2014 | 2014-Ohio-2476
State v. Bayless | CA2013-10-020, CA2013-10-021 | Petition For Postconviction Relief; Ineffective Assistance of Counsel; Res Judicata; The trial court did not err by denying appellant's petition for postconviction relief as his claims alleging ineffective assistance of counsel were barred by the doctrine of res judicata. | S. Powell | 6/9/2014 | 2014-Ohio-2475
State v. Waltz | CA2013-10-077 | Custody modification; R.C. 3109.04(F)(1) and best interest; required finding under R.C. 3109.04(E)(1)(a)(iii) implicitly made by trial court; guardian ad litem performance; Sup.R. 48(D)(13). | M. Powell | 6/9/2014 | 2014-Ohio-2474
Hunter-June v. Pitts | CA2013-09-178 | Custody modification; R.C. 3109.04(F)(1) and best interest; required finding under R.C. 3109.04(E)(1)(a)(iii) implicitly made by trial court; guardian ad litem performance; Sup.R. 48(D)(13); in camera interviews of the children not preserved. | M. Powell | 6/9/2014 | 2014-Ohio-2473
State v. Morgan | CA2013-08-146, CA2013-08-147 | Motion to Suppress; Crim.R. 41(A); R.C. 1717.06; Qualified Humane Agent; Animal Cruelty; R.C. 959.13(A); Sufficient Evidence; Not Against Manifest Weight of the Evidence; Other Acts Evidence; Evid.R. 404(B); Other Purpose; Prosecutorial Misconduct; Closing Argument; Proper Statement Regarding Submitted Evidence; Common Sense; No Plain Error; The trial court did not err by denying appellants' motion to suppress where search warrant was requested from properly appointed humane agent authorized by R.C. 1717.06 to seek and execute the search warrant in compliance with Crim.R. 41(A). In addition, appellants respective convictions for cruelty to animals in violation of R.C. 959.13(A)(1) were supported by sufficient evidence and not against the manifest weight of the evidence where the state provided overwhelming, uncontroverted evidence indicating a horse confined on their property and in their care was on the verge of death due to lack of sufficient food and water. Moreover, the trial court did not err, let alone commit plain error, by the introduction of so-called "other acts" evidence relating to two prior allegations of animal cruelty levied against appellants in regards to their horses as the evidence was properly used to prove their knowledge and the absence of mistake or accident. The state also did not commit prosecutorial misconduct during its closing argument as the state's comment during its rebuttal closing argument that the horse "has been starved" is not a misstatement of the law, nor did such comment have the potential to confuse or mislead the jury in any way. Finally, a request by the state during its closing argument for the jury to use its common sense has been determined to be neither prosecutorial misconduct, nor plain error. | S. Powell | 6/9/2014 | 2014-Ohio-2472
State v. Doby | CA2013-05-084 | Evidence; Confrontation Clause; Testimonial; Jury Instructions; Murder; Voluntary Manslaughter; Prosecutorial Misconduct; Hearsay. | M. Powell | 6/9/2014 | 2014-Ohio-2471
Klan v. Med. Radiologists, Inc. | CA2014-01-007 | Motion to Dismiss; Notice Pleading; Without Prejudice; Civ.R. 12(B)(6); Civ.R. 8(A); The trial court did not err by dismissing appellant's complaint against appellees pursuant to Civ.R. 12(B)(6) where he failed to meet the minimal pleading requirements found under Civ.R. 8(A). However, the trial court did err by dismissing appellant's complaint with prejudice where he could have properly pled the claim in another way, so as to set forth sufficient underlying facts that relate to and support the alleged abuse of process claim. A dismissal for failure to state a claim is without prejudice except in those cases where the claim cannot be pleaded in any other way. | S. Powell | 6/2/2014 | 2014-Ohio-2344
Jewett v. Jewett | CA2013-11-110 | Interpretation and Clarification; QDRO; Retirement and Pension Benefits; Accrued Benefits; The trial court's interpretation and clarification of the QDRO as it relates to the term "accrued benefits" was proper and is consistent with the trial court's clear intent for appellee to receive one-half share of the marital portion of appellant's pension plan, regardless of how those benefits may be classified thereafter. | S. Powell | 6/2/2014 | 2014-Ohio-2343
State v. Wilson | CA2013-10-034 | Motion for postconviction relief; R.C. 2953.21; evidentiary hearing; findings of fact; conclusions of law; ineffective assistance; minimum prison term; motion to suppress; statements made to law enforcement. | Hendrickson | 6/2/2014 | 2014-Ohio-2342
State v. Kilbarger | CA2013-04-013 | Rape; R.C. 2907.02(A)(1)(c); gross sexual imposition; R.C. 2907.05(A)(5); victim's ability to consent was substantially impaired because of a mental condition; manifest weight of the evidence. | M. Powell | 6/2/2014 | 2014-Ohio-2341
State v. Setty | CA2013-06-049, CA2013-06-050 | Rape; attempted rape; sexual battery; disseminating matter harmful to juveniles; felonious assault; multiple indictments; motion in limine; proffer of evidence; expert qualifications; Evid.R. 702; prosecutorial misconduct; closing statements; plain error; ineffective assistance of counsel; scope of cross-examination; leading questions; deficient performance; manifest weight of the evidence; insufficient evidence; credibility determination by trier of fact; penetration; serious physical harm; obscene material; principles and purposes of sentencing; consecutive sentences; permissible statutory range; R.C. 2907.02(B). | Hendrickson | 6/2/2014 | 2014-Ohio-2340
In re R.E. | CA2013-12-245 | Permanent custody; manifest weight best interest; case plan requirements; domestic violence. | Hendrickson | 6/2/2014 | 2014-Ohio-2338
State v. Florence | CA2013-08-148 | Sufficiency of the evidence; obstructing official business; disorderly conduct; R.C. 2917.11(B)(1); R.C. 2917.11(E)(3); right to allocution; Crim.R. 32; misdemeanor sentencing; R.C. 2929.21; R.C. 2929.22; court costs; community service; R.C. 2947.23. | M. Powell | 6/2/2014 | 2014-Ohio-2337
State ex rel. Miller v. Ohio State Hwy. Patrol | CA2012-05-034 | The relator is not entitled to damages and fees because the records he requested fell within the investigatory work product exception to the Ohio Public Records Act so that respondent did not violate the act by not producing the records where the records were created by law enforcement with the intent to be used in a future criminal proceeding. | Per Curiam | 5/27/2014 | 2014-Ohio-2244
State v. Lyons | CA2013-08-074 | Restitution; Hearsay; Reasonable Certainty. | Ringland | 5/27/2014 | 2014-Ohio-2239
State v. Kinsworthy | CA2013-06-060 | Civil Protection Order; Manifest Weight; Insufficient Evidence; R.C. 2929.21; R.C. 2929.22; Misdemeanor Sentencing; Consecutive Sentences; Financial Sanctions. | Ringland | 5/27/2014 | 2014-Ohio-2238
Renner v. Renner | CA2014-01-004 | The trial court did not abuse its discretion by awarding appellee custody of the parties' child where such was in the child's best interest and where the trial court considered all relevant evidence, including testimony of appellant's expert witness, when balancing the best interest factors. | Piper | 5/27/2014 | 2014-Ohio-2237
State v. Daugherty | CA2013-08-063 | Post-Sentence Motion to Withdraw Guilty Plea; Sentence; Issue Not Raised Before Trial Court; Waiver; Ineffective Assistance; Bias; Appellant waived argument regarding the trial court's sentencing decision where he did not raise the issue within his post-sentence motion to withdraw his guilty plea. However, even if not waived, a review of the record does not establish any error in the trial court's sentencing decision ordering appellant to serve a jointly recommended mandatory eight-year prison term resulting from his guilty plea to aggravated vehicular homicide. In addition, the trial court did not err by denying appellant's post-sentence motion to withdraw his guilty plea where appellant failed to show he received ineffective assistance from his trial counsel's alleged failure to disclose his alleged bias due to counsel's prior representation of the victim's uncle and local bar where accident occurred. | S. Powell | 5/27/2014 | 2014-Ohio-2236
State v. Steinmetz | CA2013-10-185 | Guilty Plea; Plea Colloquy; Crim.R. 11(C); Plea Agreement; Crim.R. 11(F). | S. Powell | 5/27/2014 | 2014-Ohio-2235
State v. Blanda | CA2013-06-109 | Postconviction Relief; Res Judicata; Jury Questions During Deliberation; In-Chambers Discussion; Written Response to Jury Question; Not Critical Stage; Felony Murder; Essential Elements; Causation and Foreseeability; The trial court did not err by denying appellant's petition for postconviction relief as his claims regarding the trial court's responses to the jury's questions during deliberations were barred by the doctrine of res judicata. In addition, in-chambers discussion regarding the trial court's written responses to the jury's questions regarding the essential elements of felony murder was not a critical stage of the proceedings requiring appellant's presence. Finally, the trial court's written response to the jury's question during deliberation regarding the essential elements of felony murder was proper as causation is an essential element of the crime, whereas foreseeability is not. When viewed as a whole, there is no indication that the jury instructions regarding the essential elements of felony murder would confuse or mislead the jury so as to constitute prejudicial error. | S. Powell | 5/27/2014 | 2014-Ohio-2234
State v. Reeder | CA2013-05-075, CA2013-07-126 | Defendant-appellant appeals his conviction following a guilty plea to one count of rape and sentencing to nine years imprisonment. Appellant argues that his plea was not knowing, intelligent, and voluntary; that the court improperly denied his motion to withdraw; that his counsel was ineffective; and that the trial court failed to advise him of the potential for community service if he failed to pay court costs. Appellant's guilty plea was knowing, intelligent, and voluntary because appellant received a full Crim.R. 11 plea colloquy, and the totality of circumstances indicate that he subjectively understood the consequences of his plea. The trial court did not abuse its discretion when it denied appellant's Crim.R. 32.1 post-sentence motion to withdraw because appellant failed to demonstrate manifest injustice. Appellant waived his right to claim ineffective assistance of counsel when he entered a guilty plea, except to the extent the defects caused the plea to be less than knowing and voluntary. Appellant entered a knowing, intelligent, and voluntary plea, so he is precluded from claiming ineffective assistance of counsel. The trial court did not err in failing to notify appellant that it could order him to perform community service in the event he did not pay imposed court costs because R.C. 2947.23(A)(1) provides that this failure does not negate or limit the authority of the court to order appellant to perform community service. | Ringland | 5/27/2014 | 2014-Ohio-2233
State v. Furr | CA2013-04-066 | Motion to Withdraw Guilty Plea; Jurisdiction; Res Judicata: Trial court erred in determining it lacked jurisdiction to rule on appellant's motion to withdraw guilty plea; while trial court was temporarily divested of jurisdiction when appellant filed a notice of appeal with court of appeals, it regained jurisdiction to rule on appellant's motion when court of appeals dismissed appellant's appeal without addressing its substantive merits. Trial court erred in finding it was precluded by res judicata from ruling on appellant's motion to withdraw his guilty plea, because neither the trial court nor court of appeals had ruled on the merits of appellant's motion and all but one of the claims appellant raised in support of his motion could not have been raised on direct appeal following his conviction. | Ringland | 5/20/2014 | 2014-Ohio-2138
State v. Davis | CA2013-12-129, CA2013-12-130 | Intervention in Lieu of Conviction; R.C. 2951.041(F); Clear and Unambiguous; The trial court erred by allowing appellee to continue on his intervention in lieu of conviction treatment after serving only four days in jail as a result of his admitted violation to the terms and conditions of his ILC. The clear and unambiguous language of R.C. 2951.041(F) requires the trial court to sentence a defendant who is found to have failed his or her program of treatment in lieu of conviction to an appropriate sanction under R.C. Chapter 2929. | S. Powell | 5/19/2014 | 2014-Ohio-2122
Marron v. Marron | CA2013-11-109, CA2013-11-113 | Child Support; Spousal Support; Income; Voluntarily Underemployed; Imputation of Income; K-1 Income. | Piper | 5/19/2014 | 2014-Ohio-2121
Odom Industries, Inc. v. Shoupe | CA2013-09-069 | Unemployment compensation; just cause; R.C. 4141.29. | Hendrickson | 5/19/2014 | 2014-Ohio-2120
In re Guardianship of Smith | CA2013-09-165 | Guardianship; third-party appointed guardian; denial of parents' application to be appointed guardian of their adult son; restrictive alternatives to guardianship not introduced at guardianship hearing; R.C. 2111.02(C). | M. Powell | 5/19/2014 | 2014-Ohio-2119
State v. Combs | CA2013-08-008 | Defendant-appellant was arrested for a violation of R.C. 2950.05 after an officer from the Brown County Sheriff's Office found him living in a motel room in Ripley, Ohio. Appellant, a convicted sex offender, had registered his parents address as his residence. He was convicted of failure to provide notice of a change of address after a bench trial. On appeal, appellant challenges the sufficiency of the evidence. An individual can have more than one "residence," under the everyday meaning of the term. R.C. 2905.05 requires that the sex offenders to which it applies register any change of address, including the acquisition of a second residence. Therefore, there was sufficient evidence to convict appellant pursuant to R.C. 2950.05 where a rational trier of fact could have found that he acquired a second residence and did not register it. | Piper | 5/19/2014 | 2014-Ohio-2117
In re M.N. | CA2013-12-135; CA2013-12 136 | Anders no error. | Per Curiam | 5/12/2014 | 2014-Ohio-2009
State v. Rabe | CA2013-09-068 | Appellant's motion to suppress was properly denied by the trial court where the officers had probable cause to arrest appellant for his crimes and where the highway patrol trooper performed field sobriety tests properly. The trial court did not abuse its discretion by closing discovery on the date it allowed appellant to substitute his counsel where the record demonstrates that there was no new evidence to be discovered that could not have been discovered prior to appellant making his motion to substitute counsel. Appellant did not receive ineffective assistance of counsel were the record demonstrates that using a different tactic at the motion to suppress hearing would not have resulted in the motion being granted, and where the record shows that even if counsel had objected to a photograph as being inadmissible, the photograph was admissible. Appellant's convictions were supported by sufficient evidence and were not against the manifest weight of the evidence where the state presented testimony and evidence from witnesses to the accident and investigating officers that appellant was driving under the influence of alcohol when he caused an accident and fled the scene. The trial court properly sentenced appellant to pay restitution and fines after considering appellant's present and future ability to pay. The trial court properly sentenced appellant to three years in prison after considering the purposes and principles of sentencing as is required by the sentencing statute. | Piper | 5/12/2014 | 2014-Ohio-2008
In re E.G. | CA2013-12-224 | Permanent custody; best interest; autism; substance abuse; treatment. | Piper | 5/12/2014 | 2014-Ohio-2007
Learning Tree Academy, Ltd. v. Holeyfield | CA2013-10-194 | The trial court lacked jurisdiction to convert appellee's Civ.R. 60(B) motion to a motion for leave to file objections out of time once the trial court had issued its final decision, adopting the magistrate's decision. | Piper | 5/12/2014 | 2014-Ohio-2006
BAC Home Loans Servicing, L.P. v. Mapp | CA2013-10-193 | Motion to Vacate; Foreclosure; Standing; Interest in Note and Mortgage; Motion for Relief From Judgment; Civ.R. 60(B); No Abuse of Discretion; The trial court did not err by denying appellant's motion to vacate where appellee established that it had an interest in both the note and mortgage, either of which were sufficient to establish standing, at the time it filed its complaint in foreclosure. The trial court did not abuse its discretion by denying appellant's motion for relief from judgment as he failed to present the necessary operative facts in order to establish a meritorious defense. Beyond his own general allegations, appellant provided no evidence to support his claim that the mortgage documents were somehow forged, altered or otherwise tampered with. In addition, changes to appellant's business and impending divorce did not constitute excusable neglect for his failure to respond to appellee's motion for summary judgment. | S. Powell | 5/12/2014 | 2014-Ohio-2005
State v. Swift | CA2013-08-161 | Motion to Suppress; Marijuana Cultivation; Search Warrant; Fourth Amendment; Sentence; Contrary to Law. | Ringland | 5/12/2014 | 2014-Ohio-2004
Motorists Mut. Ins. Co. v. Roberts | CA2013-09-089 | Service of process; Civ.R. 4.6(D); Business Records Exception, void judgment; Civ.R. 60(B). | M. Powell | 5/5/2014 | 2014-Ohio-1893
Burchwell v. Warren Cty. | CA2013-09-079 | Declaratory judgment; motion to dismiss; Civ.R. 12(B)(6); failure to state a claim; Civ.R. 52; findings of fact; conclusions of law; abuse of discretion. | Ringland | 5/5/2014 | 2014-Ohio-1892
State v. Graham | CA2013-07-066 | Sentencing; Disparity in Sentencing; Consistent Sentencing; Ineffective Assistance of Counsel; Waiver. | Hendrickson | 5/5/2014 | 2014-Ohio-1891
Kairn v. Clark | CA2013-06-059, CA2013-08-071 | Child Support; Voluntary Unemployment; Imputed Income; Imprisonment; R.C. 3119.05(I)(2). | Ringland | 5/5/2014 | 2014-Ohio-1890
Williams v. Bur. of Workers' Comp. | CA2013-09-006 | Summary Judgment; Workers' Compensation; Six-Year Time Limitation Period; R.C. 4123.52; The trial court did not err by granting summary judgment to appellee in appellant's claim for workers' compensation benefits where the six-year limitation period found in R.C.4123.52 had expired. Appellant's motion seeking to add an additional condition did not constitute an application for compensation. | S. Powell | 5/5/2014 | 2014-Ohio-1889
Huegemann v. VanBakel | CA2013-08-022 | Final Appealable Order; Provisional Remedy; Denial of Motion To Dismiss For Lack of Personal Jurisdiction: Trial court's order overruling appellants' motion to dismiss for lack of personal jurisdiction was a final order because (1) it is a "provisional remedy" as defined in R.C. 2505.02(A)(3), since it is a proceeding ancillary to an action that it is attendant upon or aids another proceeding, or grows out of and is auxiliary to another suit and is filed to aid the primary suit; (2) the order, in effect, determined the action with respect to the provisional remedy, because it permits appellees to proceed with their action against appellants; (3) forcing appellants to delay their appeal until final judgment is entered will deny them a meaningful or effective remedy. Personal Jurisdiction; Nonresident Parties; Long-arm Jurisdiction, Due Process, R.C. 2307.382, Civ.R. 4.3; Ohio's Corrupt Activity Act: Trial court did not err in overruling the motion to dismiss for lack of personal jurisdiction raised by several nonresident appellants named as defendants in an action brought against them under Ohio's Corrupt Activity Act in R.C. 2923.31 et seq.; the allegations in appellees' complaint and the evidence in the record, when viewed in a light most favorable to appellees as the nonmoving party, showed that appellants' conduct fell within Ohio's "long-arm" statute in R.C. 2307.382 and Civ.R.4.3 and that trial court's assertion of jurisdiction over appellants did not deprive them of due process. | Ringland | 5/5/2014 | 2014-Ohio-1888
Fox v. Fox | CA2013-08-066 | Relationship between former spouse and paramour; motion to terminate spousal support; cohabitation; pre-divorce decree evidence of relationship between former spouse and paramour excluded by trial court; notwithstanding magistrate's erroneous finding that cohabitation requires sexual relations, trial court properly adopted magistrate's decision rather than remanding matter to magistrate; Civ.R. 53(D)(4)(d). | M. Powell | 5/5/2014 | 2014-Ohio-1887
M&T Bank v. Johns | CA2013-04-032 | Foreclosure; Standing; Business Records. | Ringland | 5/5/2014 | 2014-Ohio-1886
State v. Ruffin | CA2013-11-208 | Anders no error. | Per Curiam | 5/5/2014 | 2014-Ohio-1885
Dollries v. Dollries | CA2012-08-167, CA2012-11-234 | The trial court did not abuse its discretion by valuing the business as it did because the trial court's finding that the valuation offered by appellee's expert was supported by the record. However, the trial court's decision regarding adjustments made to the valuation of the business was not supported by the record. The trial court did not consider the tax consequences of the property division so that on remand, the trial court must demonstrate that it considered the applicable tax consequences of dividing the business. The trial court did not abuse its discretion by not allowing husband to offer rebuttal testimony where the parties themselves asked for a three-hour hearing and were both constrained to that time limit. The trial court abused its discretion by adding $120,000 in perks to appellant's income where that figure was not supported by the record. The trial court did not abuse its discretion in ordering appellant to pay appellee $6,000 per month for approximately 32 years to compensation appellee for her portion of the marital interest where the circumstances indicated that appellant had limited cash flow and the trial court otherwise protected appellee's interest to guarantee that it would be paid. | Piper | 5/5/2014 | 2014-Ohio-1883
State v. Brown | CA2013-11-206 | Anders no error. | Per Curiam | 4/28/2014 | 2014-Ohio-1798
State v. Bishop | CA2013-06-098 | The trial court should have addressed appellant's motion to waive court costs because the motion was properly pending at the time the trial court resentenced appellant according to R.C. 2947.23. | Piper | 4/28/2014 | 2014-Ohio-1797
Bank of New York Mellon v. Putman | CA2012-12-267 | Summary Judgment; Foreclosure; Standing; Interest in Note and Mortgage; Motion to Strike; Affidavit; Loan Servicing Agent; No Abuse of Discretion; The trial court did not err by granting summary judgment to plaintiff-appellee where it established it had an interest in both the note and the mortgage, either of which were sufficient to establish standing, at the time it filed its complaint for foreclosure. In addition, the trial court did not err or abuse its discretion by denying appellant's motion to strike an affidavit from a loan servicing agent as affidavits from a loan servicing agent are proper summary judgment evidence in foreclosure actions. | S. Powell | 4/28/2014 | 2014-Ohio-1796
State v. Conley | CA2013-06-055 | Sufficiency of the evidence; criminal damaging; R.C. 2909.06; consent. | Hendrickson | 4/21/2014 | 2014-Ohio-1699
Fannie Mae v. Winding | CA2013-09-179 | Survivorship Tenancy; Constructive Trust; Equitable Lien; Purchase-Money Resulting Trust; Foreclosure; Mortgage. | Ringland | 4/21/2014 | 2014-Ohio-1698
State v. Applegate | CA2013-08-070 | Aggravated menacing; aggravated trespassing; manifest weight of the evidence; customer's threat to retrieve assault rifle from his vehicle and "clean house;" and customer's refusal to leave the store following his threatening comment despite a request to do so. | M. Powell | 4/21/2014 | 2014-Ohio-1697
State v. McCullough | CA2013-07-021 | Motion To Suppress; Stop of Vehicle; Traffic Violation; Canine Sniff; Reasonable and Articulable Suspicion of Drug Activity Not Require; No Impermissible Expansion of the Stop; Inevitable-Discovery Doctrine; Probable Cause; The trial court did not err by denying appellant's motion to suppress where the initial stop of her vehicle was supported by probable cause after officers observed her vehicle traveling at a speed above the posted speed limit. This is true even though the officers may have had an ulterior motive for making the stop, such as their suspicion that she was engaged in more serious criminal drug activity. The trial court also did not err by denying appellant's motion to suppress as the officers were not required to have a reasonable and articulable suspicion of drug activity before conducting a canine sniff of her vehicle. Moreover, appellant's subsequent detention during which a canine sniff of her vehicle was conducted did not impermissibly extend her detention as the canine sniff was done within mere minutes after the officers stopped her vehicle. Finally, the trial court did not err by denying appellant's motion to suppress by finding the inevitable-discovery doctrine applied. Although appellant may have been subject to an unconstitutional search of her person once transported to jail, the officers were in the process of typing up a search warrant, which, based on the facts and circumstances of the case, provided more than enough evidence to support a probable cause finding to issue a search warrant. | S. Powell | 4/21/2014 | 2014-Ohio-1696
State v. Alltop | CA2013-06-018 | Defendant-appellant appeals his conviction for aggravated robbery, arguing that the trial court improperly denied both his motion for an appropriation of funds for a DNA/Forensics expert, and his motion to suppress DNA evidence collected from his boots without a warrant. The trial court's denial of appellant's motion for an appropriation of funds for a DNA/Forensics expert was not an abuse of discretion because appellant failed to make a particularized showing that (1) there was a reasonable probability that the requested expert would aid in his defense, and (2) the denial of the requested assistance would result in an unfair trial. The trial court did not err in denying appellant's motion to suppress the evidence obtained as a result of the DNA testing of his boots because the evidence was collected through a search incident to arrest. A "search incident to arrest" is a well-established exception to the general rule against warrantless searches that allows arresting officers to search both an arrestee's person and the area within the arrestee's immediate control. | M. Powell | 4/21/2014 | 2014-Ohio-1695

Page: [ 1] 2 next